Class DefaultMachineLearningEndpointProvider
java.lang.Object
software.amazon.awssdk.services.machinelearning.endpoints.internal.DefaultMachineLearningEndpointProvider
- All Implemented Interfaces:
EndpointProvider,MachineLearningEndpointProvider
@Generated("software.amazon.awssdk:codegen")
@SdkInternalApi
public final class DefaultMachineLearningEndpointProvider
extends Object
implements MachineLearningEndpointProvider
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleaninthashCode()Compute the endpoint based on the given set of parameters.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface software.amazon.awssdk.services.machinelearning.endpoints.MachineLearningEndpointProvider
resolveEndpoint
-
Constructor Details
-
DefaultMachineLearningEndpointProvider
public DefaultMachineLearningEndpointProvider()
-
-
Method Details
-
resolveEndpoint
Description copied from interface:MachineLearningEndpointProviderCompute the endpoint based on the given set of parameters.- Specified by:
resolveEndpointin interfaceMachineLearningEndpointProvider
-
equals
-
hashCode
public int hashCode()
-