Class CreateBatchPredictionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CreateBatchPredictionRequest.Builder,CreateBatchPredictionRequest>

@Generated("software.amazon.awssdk:codegen") public final class CreateBatchPredictionRequest extends MachineLearningRequest implements ToCopyableBuilder<CreateBatchPredictionRequest.Builder,CreateBatchPredictionRequest>
  • Method Details

    • batchPredictionId

      public final String batchPredictionId()

      A user-supplied ID that uniquely identifies the BatchPrediction.

      Returns:
      A user-supplied ID that uniquely identifies the BatchPrediction.
    • batchPredictionName

      public final String batchPredictionName()

      A user-supplied name or description of the BatchPrediction. BatchPredictionName can only use the UTF-8 character set.

      Returns:
      A user-supplied name or description of the BatchPrediction. BatchPredictionName can only use the UTF-8 character set.
    • mlModelId

      public final String mlModelId()

      The ID of the MLModel that will generate predictions for the group of observations.

      Returns:
      The ID of the MLModel that will generate predictions for the group of observations.
    • batchPredictionDataSourceId

      public final String batchPredictionDataSourceId()

      The ID of the DataSource that points to the group of observations to predict.

      Returns:
      The ID of the DataSource that points to the group of observations to predict.
    • outputUri

      public final String outputUri()

      The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results. The following substrings are not allowed in the s3 key portion of the outputURI field: ':', '//', '/./', '/../'.

      Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the Amazon Machine Learning Developer Guide.

      Returns:
      The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results. The following substrings are not allowed in the s3 key portion of the outputURI field: ':', '//', '/./', '/../'.

      Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the Amazon Machine Learning Developer Guide.

    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<CreateBatchPredictionRequest.Builder,CreateBatchPredictionRequest>
      Specified by:
      toBuilder in class MachineLearningRequest
    • builder

      public static CreateBatchPredictionRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends CreateBatchPredictionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo