Interface CreateBatchPredictionRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<CreateBatchPredictionRequest.Builder,,CreateBatchPredictionRequest> MachineLearningRequest.Builder,SdkBuilder<CreateBatchPredictionRequest.Builder,,CreateBatchPredictionRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- CreateBatchPredictionRequest
-
Method Summary
Modifier and TypeMethodDescriptionbatchPredictionDataSourceId(String batchPredictionDataSourceId) The ID of theDataSourcethat points to the group of observations to predict.batchPredictionId(String batchPredictionId) A user-supplied ID that uniquely identifies theBatchPrediction.batchPredictionName(String batchPredictionName) A user-supplied name or description of theBatchPrediction.The ID of theMLModelthat will generate predictions for the group of observations.The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.services.machinelearning.model.MachineLearningRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
batchPredictionId
A user-supplied ID that uniquely identifies the
BatchPrediction.- Parameters:
batchPredictionId- A user-supplied ID that uniquely identifies theBatchPrediction.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
batchPredictionName
A user-supplied name or description of the
BatchPrediction.BatchPredictionNamecan only use the UTF-8 character set.- Parameters:
batchPredictionName- A user-supplied name or description of theBatchPrediction.BatchPredictionNamecan only use the UTF-8 character set.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
mlModelId
The ID of the
MLModelthat will generate predictions for the group of observations.- Parameters:
mlModelId- The ID of theMLModelthat will generate predictions for the group of observations.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
batchPredictionDataSourceId
CreateBatchPredictionRequest.Builder batchPredictionDataSourceId(String batchPredictionDataSourceId) The ID of the
DataSourcethat points to the group of observations to predict.- Parameters:
batchPredictionDataSourceId- The ID of theDataSourcethat points to the group of observations to predict.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
outputUri
The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results. The following substrings are not allowed in the
s3 keyportion of theoutputURIfield: ':', '//', '/./', '/../'.Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the Amazon Machine Learning Developer Guide.
- Parameters:
outputUri- The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results. The following substrings are not allowed in thes3 keyportion of theoutputURIfield: ':', '//', '/./', '/../'.Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the Amazon Machine Learning Developer Guide.
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
CreateBatchPredictionRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
CreateBatchPredictionRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-