Class CreateDataSourceFromRdsResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.machinelearning.model.MachineLearningResponse
software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateDataSourceFromRdsResponse.Builder,CreateDataSourceFromRdsResponse>
@Generated("software.amazon.awssdk:codegen")
public final class CreateDataSourceFromRdsResponse
extends MachineLearningResponse
implements ToCopyableBuilder<CreateDataSourceFromRdsResponse.Builder,CreateDataSourceFromRdsResponse>
Represents the output of a CreateDataSourceFromRDS operation, and is an acknowledgement that Amazon ML
received the request.
The CreateDataSourceFromRDS> operation is asynchronous. You can poll for updates by using the
GetBatchPrediction operation and checking the Status parameter. You can inspect the
Message when Status shows up as FAILED. You can also check the progress of the
copy operation by going to the DataPipeline console and looking up the pipeline using the
pipelineId from the describe call.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringA user-supplied ID that uniquely identifies the datasource.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends CreateDataSourceFromRdsResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.machinelearning.model.MachineLearningResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
dataSourceId
A user-supplied ID that uniquely identifies the datasource. This value should be identical to the value of the
DataSourceIDin the request.- Returns:
- A user-supplied ID that uniquely identifies the datasource. This value should be identical to the value
of the
DataSourceIDin the request.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateDataSourceFromRdsResponse.Builder,CreateDataSourceFromRdsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-