Class CreateDataSourceFromRedshiftRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CreateDataSourceFromRedshiftRequest.Builder,CreateDataSourceFromRedshiftRequest>

@Generated("software.amazon.awssdk:codegen") public final class CreateDataSourceFromRedshiftRequest extends MachineLearningRequest implements ToCopyableBuilder<CreateDataSourceFromRedshiftRequest.Builder,CreateDataSourceFromRedshiftRequest>
  • Method Details

    • dataSourceId

      public final String dataSourceId()

      A user-supplied ID that uniquely identifies the DataSource.

      Returns:
      A user-supplied ID that uniquely identifies the DataSource.
    • dataSourceName

      public final String dataSourceName()

      A user-supplied name or description of the DataSource.

      Returns:
      A user-supplied name or description of the DataSource.
    • dataSpec

      public final RedshiftDataSpec dataSpec()

      The data specification of an Amazon Redshift DataSource:

      • DatabaseInformation -

        • DatabaseName - The name of the Amazon Redshift database.

        • ClusterIdentifier - The unique ID for the Amazon Redshift cluster.

      • DatabaseCredentials - The AWS Identity and Access Management (IAM) credentials that are used to connect to the Amazon Redshift database.

      • SelectSqlQuery - The query that is used to retrieve the observation data for the Datasource.

      • S3StagingLocation - The Amazon Simple Storage Service (Amazon S3) location for staging Amazon Redshift data. The data retrieved from Amazon Redshift using the SelectSqlQuery query is stored in this location.

      • DataSchemaUri - The Amazon S3 location of the DataSchema.

      • DataSchema - A JSON string representing the schema. This is not required if DataSchemaUri is specified.

      • DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the DataSource.

        Sample - "{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"

      Returns:
      The data specification of an Amazon Redshift DataSource:

      • DatabaseInformation -

        • DatabaseName - The name of the Amazon Redshift database.

        • ClusterIdentifier - The unique ID for the Amazon Redshift cluster.

      • DatabaseCredentials - The AWS Identity and Access Management (IAM) credentials that are used to connect to the Amazon Redshift database.

      • SelectSqlQuery - The query that is used to retrieve the observation data for the Datasource.

      • S3StagingLocation - The Amazon Simple Storage Service (Amazon S3) location for staging Amazon Redshift data. The data retrieved from Amazon Redshift using the SelectSqlQuery query is stored in this location.

      • DataSchemaUri - The Amazon S3 location of the DataSchema.

      • DataSchema - A JSON string representing the schema. This is not required if DataSchemaUri is specified.

      • DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the DataSource.

        Sample - "{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"

    • roleARN

      public final String roleARN()

      A fully specified role Amazon Resource Name (ARN). Amazon ML assumes the role on behalf of the user to create the following:

      • A security group to allow Amazon ML to execute the SelectSqlQuery query on an Amazon Redshift cluster

      • An Amazon S3 bucket policy to grant Amazon ML read/write permissions on the S3StagingLocation

      Returns:
      A fully specified role Amazon Resource Name (ARN). Amazon ML assumes the role on behalf of the user to create the following:

      • A security group to allow Amazon ML to execute the SelectSqlQuery query on an Amazon Redshift cluster

      • An Amazon S3 bucket policy to grant Amazon ML read/write permissions on the S3StagingLocation

    • computeStatistics

      public final Boolean computeStatistics()

      The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.

      Returns:
      The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<CreateDataSourceFromRedshiftRequest.Builder,CreateDataSourceFromRedshiftRequest>
      Specified by:
      toBuilder in class MachineLearningRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends CreateDataSourceFromRedshiftRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo