Class CreateDataSourceFromRedshiftResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.machinelearning.model.MachineLearningResponse
software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRedshiftResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateDataSourceFromRedshiftResponse.Builder,CreateDataSourceFromRedshiftResponse>
@Generated("software.amazon.awssdk:codegen")
public final class CreateDataSourceFromRedshiftResponse
extends MachineLearningResponse
implements ToCopyableBuilder<CreateDataSourceFromRedshiftResponse.Builder,CreateDataSourceFromRedshiftResponse>
Represents the output of a CreateDataSourceFromRedshift operation, and is an acknowledgement that Amazon
ML received the request.
The CreateDataSourceFromRedshift operation is asynchronous. You can poll for updates by using the
GetBatchPrediction operation and checking the Status parameter.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringA user-supplied ID that uniquely identifies the datasource.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends CreateDataSourceFromRedshiftResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.machinelearning.model.MachineLearningResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
dataSourceId
A user-supplied ID that uniquely identifies the datasource. This value should be identical to the value of the
DataSourceIDin the request.- Returns:
- A user-supplied ID that uniquely identifies the datasource. This value should be identical to the value
of the
DataSourceIDin the request.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateDataSourceFromRedshiftResponse.Builder,CreateDataSourceFromRedshiftResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends CreateDataSourceFromRedshiftResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-