Class CreateDataSourceFromS3Request

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CreateDataSourceFromS3Request.Builder,CreateDataSourceFromS3Request>

@Generated("software.amazon.awssdk:codegen") public final class CreateDataSourceFromS3Request extends MachineLearningRequest implements ToCopyableBuilder<CreateDataSourceFromS3Request.Builder,CreateDataSourceFromS3Request>
  • Method Details

    • dataSourceId

      public final String dataSourceId()

      A user-supplied identifier that uniquely identifies the DataSource.

      Returns:
      A user-supplied identifier that uniquely identifies the DataSource.
    • dataSourceName

      public final String dataSourceName()

      A user-supplied name or description of the DataSource.

      Returns:
      A user-supplied name or description of the DataSource.
    • dataSpec

      public final S3DataSpec dataSpec()

      The data specification of a DataSource:

      • DataLocationS3 - The Amazon S3 location of the observation data.

      • DataSchemaLocationS3 - The Amazon S3 location of the DataSchema.

      • DataSchema - A JSON string representing the schema. This is not required if DataSchemaUri is specified.

      • DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the Datasource.

        Sample - "{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"

      Returns:
      The data specification of a DataSource:

      • DataLocationS3 - The Amazon S3 location of the observation data.

      • DataSchemaLocationS3 - The Amazon S3 location of the DataSchema.

      • DataSchema - A JSON string representing the schema. This is not required if DataSchemaUri is specified.

      • DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the Datasource.

        Sample - "{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"

    • computeStatistics

      public final Boolean computeStatistics()

      The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.

      Returns:
      The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<CreateDataSourceFromS3Request.Builder,CreateDataSourceFromS3Request>
      Specified by:
      toBuilder in class MachineLearningRequest
    • builder

      public static CreateDataSourceFromS3Request.Builder builder()
    • serializableBuilderClass

      public static Class<? extends CreateDataSourceFromS3Request.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo