Class CreateMlModelRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateMlModelRequest.Builder,CreateMlModelRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic CreateMlModelRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Parameters property.final StringA user-supplied ID that uniquely identifies theMLModel.final StringA user-supplied name or description of theMLModel.final MLModelTypeThe category of supervised learning that thisMLModelwill address.final StringThe category of supervised learning that thisMLModelwill address.A list of the training parameters in theMLModel.final Stringrecipe()The data recipe for creating theMLModel.final StringThe Amazon Simple Storage Service (Amazon S3) location and file name that contains theMLModelrecipe.static Class<? extends CreateMlModelRequest.Builder>final StringtoString()Returns a string representation of this object.final StringTheDataSourcethat points to the training data.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
mlModelId
A user-supplied ID that uniquely identifies the
MLModel.- Returns:
- A user-supplied ID that uniquely identifies the
MLModel.
-
mlModelName
A user-supplied name or description of the
MLModel.- Returns:
- A user-supplied name or description of the
MLModel.
-
mlModelType
The category of supervised learning that this
MLModelwill address. Choose from the following types:-
Choose
REGRESSIONif theMLModelwill be used to predict a numeric value. -
Choose
BINARYif theMLModelresult has two possible values. -
Choose
MULTICLASSif theMLModelresult has a limited number of values.
For more information, see the Amazon Machine Learning Developer Guide.
If the service returns an enum value that is not available in the current SDK version,
mlModelTypewill returnMLModelType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommlModelTypeAsString().- Returns:
- The category of supervised learning that this
MLModelwill address. Choose from the following types:-
Choose
REGRESSIONif theMLModelwill be used to predict a numeric value. -
Choose
BINARYif theMLModelresult has two possible values. -
Choose
MULTICLASSif theMLModelresult has a limited number of values.
For more information, see the Amazon Machine Learning Developer Guide.
-
- See Also:
-
-
mlModelTypeAsString
The category of supervised learning that this
MLModelwill address. Choose from the following types:-
Choose
REGRESSIONif theMLModelwill be used to predict a numeric value. -
Choose
BINARYif theMLModelresult has two possible values. -
Choose
MULTICLASSif theMLModelresult has a limited number of values.
For more information, see the Amazon Machine Learning Developer Guide.
If the service returns an enum value that is not available in the current SDK version,
mlModelTypewill returnMLModelType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommlModelTypeAsString().- Returns:
- The category of supervised learning that this
MLModelwill address. Choose from the following types:-
Choose
REGRESSIONif theMLModelwill be used to predict a numeric value. -
Choose
BINARYif theMLModelresult has two possible values. -
Choose
MULTICLASSif theMLModelresult has a limited number of values.
For more information, see the Amazon Machine Learning Developer Guide.
-
- See Also:
-
-
hasParameters
public final boolean hasParameters()For responses, this returns true if the service returned a value for the Parameters property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
parameters
A list of the training parameters in the
MLModel. The list is implemented as a map of key-value pairs.The following is the current set of training parameters:
-
sgd.maxMLModelSizeInBytes- The maximum allowed size of the model. Depending on the input data, the size of the model might affect its performance.The value is an integer that ranges from
100000to2147483648. The default value is33554432. -
sgd.maxPasses- The number of times that the training process traverses the observations to build theMLModel. The value is an integer that ranges from1to10000. The default value is10. -
sgd.shuffleType- Whether Amazon ML shuffles the training data. Shuffling the data improves a model's ability to find the optimal solution for a variety of data types. The valid values areautoandnone. The default value isnone. We strongly recommend that you shuffle your data. -
sgd.l1RegularizationAmount- The coefficient regularization L1 norm. It controls overfitting the data by penalizing large coefficients. This tends to drive coefficients to zero, resulting in a sparse feature set. If you use this parameter, start by specifying a small value, such as1.0E-08.The value is a double that ranges from
0toMAX_DOUBLE. The default is to not use L1 normalization. This parameter can't be used whenL2is specified. Use this parameter sparingly. -
sgd.l2RegularizationAmount- The coefficient regularization L2 norm. It controls overfitting the data by penalizing large coefficients. This tends to drive coefficients to small, nonzero values. If you use this parameter, start by specifying a small value, such as1.0E-08.The value is a double that ranges from
0toMAX_DOUBLE. The default is to not use L2 normalization. This parameter can't be used whenL1is specified. Use this parameter sparingly.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasParameters()method.- Returns:
- A list of the training parameters in the
MLModel. The list is implemented as a map of key-value pairs.The following is the current set of training parameters:
-
sgd.maxMLModelSizeInBytes- The maximum allowed size of the model. Depending on the input data, the size of the model might affect its performance.The value is an integer that ranges from
100000to2147483648. The default value is33554432. -
sgd.maxPasses- The number of times that the training process traverses the observations to build theMLModel. The value is an integer that ranges from1to10000. The default value is10. -
sgd.shuffleType- Whether Amazon ML shuffles the training data. Shuffling the data improves a model's ability to find the optimal solution for a variety of data types. The valid values areautoandnone. The default value isnone. We strongly recommend that you shuffle your data. -
sgd.l1RegularizationAmount- The coefficient regularization L1 norm. It controls overfitting the data by penalizing large coefficients. This tends to drive coefficients to zero, resulting in a sparse feature set. If you use this parameter, start by specifying a small value, such as1.0E-08.The value is a double that ranges from
0toMAX_DOUBLE. The default is to not use L1 normalization. This parameter can't be used whenL2is specified. Use this parameter sparingly. -
sgd.l2RegularizationAmount- The coefficient regularization L2 norm. It controls overfitting the data by penalizing large coefficients. This tends to drive coefficients to small, nonzero values. If you use this parameter, start by specifying a small value, such as1.0E-08.The value is a double that ranges from
0toMAX_DOUBLE. The default is to not use L2 normalization. This parameter can't be used whenL1is specified. Use this parameter sparingly.
-
-
-
trainingDataSourceId
The
DataSourcethat points to the training data.- Returns:
- The
DataSourcethat points to the training data.
-
recipe
The data recipe for creating the
MLModel. You must specify either the recipe or its URI. If you don't specify a recipe or its URI, Amazon ML creates a default.- Returns:
- The data recipe for creating the
MLModel. You must specify either the recipe or its URI. If you don't specify a recipe or its URI, Amazon ML creates a default.
-
recipeUri
The Amazon Simple Storage Service (Amazon S3) location and file name that contains the
MLModelrecipe. You must specify either the recipe or its URI. If you don't specify a recipe or its URI, Amazon ML creates a default.- Returns:
- The Amazon Simple Storage Service (Amazon S3) location and file name that contains the
MLModelrecipe. You must specify either the recipe or its URI. If you don't specify a recipe or its URI, Amazon ML creates a default.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateMlModelRequest.Builder,CreateMlModelRequest> - Specified by:
toBuilderin classMachineLearningRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-