Class CreateMlModelResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.machinelearning.model.MachineLearningResponse
software.amazon.awssdk.services.machinelearning.model.CreateMlModelResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateMlModelResponse.Builder,CreateMlModelResponse>
@Generated("software.amazon.awssdk:codegen")
public final class CreateMlModelResponse
extends MachineLearningResponse
implements ToCopyableBuilder<CreateMlModelResponse.Builder,CreateMlModelResponse>
Represents the output of a CreateMLModel operation, and is an acknowledgement that Amazon ML received
the request.
The CreateMLModel operation is asynchronous. You can poll for status updates by using the
GetMLModel operation and checking the Status parameter.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringA user-supplied ID that uniquely identifies theMLModel.static Class<? extends CreateMlModelResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.machinelearning.model.MachineLearningResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
mlModelId
A user-supplied ID that uniquely identifies the
MLModel. This value should be identical to the value of theMLModelIdin the request.- Returns:
- A user-supplied ID that uniquely identifies the
MLModel. This value should be identical to the value of theMLModelIdin the request.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateMlModelResponse.Builder,CreateMlModelResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-