Class DescribeDataSourcesRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeDataSourcesRequest.Builder,DescribeDataSourcesRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringeq()The equal to operator.final booleanfinal booleanequalsBySdkFields(Object obj) final DataSourceFilterVariableUse one of the following variables to filter a list ofDataSource:final StringUse one of the following variables to filter a list ofDataSource:final Stringge()The greater than or equal to operator.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final Stringgt()The greater than operator.final inthashCode()final Stringle()The less than or equal to operator.final Integerlimit()The maximum number ofDataSourceto include in the result.final Stringlt()The less than operator.final Stringne()The not equal to operator.final StringThe ID of the page in the paginated results.final Stringprefix()A string that is found at the beginning of a variable, such asNameorId.static Class<? extends DescribeDataSourcesRequest.Builder>final SortOrderA two-value parameter that determines the sequence of the resulting list ofDataSource.final StringA two-value parameter that determines the sequence of the resulting list ofDataSource.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
filterVariable
Use one of the following variables to filter a list of
DataSource:-
CreatedAt- Sets the search criteria toDataSourcecreation dates. -
Status- Sets the search criteria toDataSourcestatuses. -
Name- Sets the search criteria to the contents ofDataSourceName. -
DataUri- Sets the search criteria to the URI of data files used to create theDataSource. The URI can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory. -
IAMUser- Sets the search criteria to the user account that invoked theDataSourcecreation.
If the service returns an enum value that is not available in the current SDK version,
filterVariablewill returnDataSourceFilterVariable.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfilterVariableAsString().- Returns:
- Use one of the following variables to filter a list of
DataSource:-
CreatedAt- Sets the search criteria toDataSourcecreation dates. -
Status- Sets the search criteria toDataSourcestatuses. -
Name- Sets the search criteria to the contents ofDataSourceName. -
DataUri- Sets the search criteria to the URI of data files used to create theDataSource. The URI can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory. -
IAMUser- Sets the search criteria to the user account that invoked theDataSourcecreation.
-
- See Also:
-
-
filterVariableAsString
Use one of the following variables to filter a list of
DataSource:-
CreatedAt- Sets the search criteria toDataSourcecreation dates. -
Status- Sets the search criteria toDataSourcestatuses. -
Name- Sets the search criteria to the contents ofDataSourceName. -
DataUri- Sets the search criteria to the URI of data files used to create theDataSource. The URI can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory. -
IAMUser- Sets the search criteria to the user account that invoked theDataSourcecreation.
If the service returns an enum value that is not available in the current SDK version,
filterVariablewill returnDataSourceFilterVariable.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfilterVariableAsString().- Returns:
- Use one of the following variables to filter a list of
DataSource:-
CreatedAt- Sets the search criteria toDataSourcecreation dates. -
Status- Sets the search criteria toDataSourcestatuses. -
Name- Sets the search criteria to the contents ofDataSourceName. -
DataUri- Sets the search criteria to the URI of data files used to create theDataSource. The URI can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory. -
IAMUser- Sets the search criteria to the user account that invoked theDataSourcecreation.
-
- See Also:
-
-
eq
The equal to operator. The
DataSourceresults will haveFilterVariablevalues that exactly match the value specified withEQ.- Returns:
- The equal to operator. The
DataSourceresults will haveFilterVariablevalues that exactly match the value specified withEQ.
-
gt
The greater than operator. The
DataSourceresults will haveFilterVariablevalues that are greater than the value specified withGT.- Returns:
- The greater than operator. The
DataSourceresults will haveFilterVariablevalues that are greater than the value specified withGT.
-
lt
The less than operator. The
DataSourceresults will haveFilterVariablevalues that are less than the value specified withLT.- Returns:
- The less than operator. The
DataSourceresults will haveFilterVariablevalues that are less than the value specified withLT.
-
ge
The greater than or equal to operator. The
DataSourceresults will haveFilterVariablevalues that are greater than or equal to the value specified withGE.- Returns:
- The greater than or equal to operator. The
DataSourceresults will haveFilterVariablevalues that are greater than or equal to the value specified withGE.
-
le
The less than or equal to operator. The
DataSourceresults will haveFilterVariablevalues that are less than or equal to the value specified withLE.- Returns:
- The less than or equal to operator. The
DataSourceresults will haveFilterVariablevalues that are less than or equal to the value specified withLE.
-
ne
The not equal to operator. The
DataSourceresults will haveFilterVariablevalues not equal to the value specified withNE.- Returns:
- The not equal to operator. The
DataSourceresults will haveFilterVariablevalues not equal to the value specified withNE.
-
prefix
A string that is found at the beginning of a variable, such as
NameorId.For example, a
DataSourcecould have theName2014-09-09-HolidayGiftMailer. To search for thisDataSource, selectNamefor theFilterVariableand any of the following strings for thePrefix:-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
- Returns:
- A string that is found at the beginning of a variable, such as
NameorId.For example, a
DataSourcecould have theName2014-09-09-HolidayGiftMailer. To search for thisDataSource, selectNamefor theFilterVariableand any of the following strings for thePrefix:-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
-
-
-
sortOrder
A two-value parameter that determines the sequence of the resulting list of
DataSource.-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by
FilterVariable.If the service returns an enum value that is not available in the current SDK version,
sortOrderwill returnSortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortOrderAsString().- Returns:
- A two-value parameter that determines the sequence of the resulting list of
DataSource.-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by
FilterVariable. -
- See Also:
-
-
sortOrderAsString
A two-value parameter that determines the sequence of the resulting list of
DataSource.-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by
FilterVariable.If the service returns an enum value that is not available in the current SDK version,
sortOrderwill returnSortOrder.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortOrderAsString().- Returns:
- A two-value parameter that determines the sequence of the resulting list of
DataSource.-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by
FilterVariable. -
- See Also:
-
-
nextToken
The ID of the page in the paginated results.
- Returns:
- The ID of the page in the paginated results.
-
limit
The maximum number of
DataSourceto include in the result.- Returns:
- The maximum number of
DataSourceto include in the result.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeDataSourcesRequest.Builder,DescribeDataSourcesRequest> - Specified by:
toBuilderin classMachineLearningRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-