Class RedshiftDatabase
java.lang.Object
software.amazon.awssdk.services.machinelearning.model.RedshiftDatabase
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RedshiftDatabase.Builder,RedshiftDatabase>
@Generated("software.amazon.awssdk:codegen")
public final class RedshiftDatabase
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<RedshiftDatabase.Builder,RedshiftDatabase>
Describes the database details required to connect to an Amazon Redshift database.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic RedshiftDatabase.Builderbuilder()final StringReturns the value of the ClusterIdentifier property for this object.final StringReturns the value of the DatabaseName property for this object.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends RedshiftDatabase.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
databaseName
Returns the value of the DatabaseName property for this object.- Returns:
- The value of the DatabaseName property for this object.
-
clusterIdentifier
Returns the value of the ClusterIdentifier property for this object.- Returns:
- The value of the ClusterIdentifier property for this object.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RedshiftDatabase.Builder,RedshiftDatabase>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-