Class UpdateMlModelRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.machinelearning.model.MachineLearningRequest
software.amazon.awssdk.services.machinelearning.model.UpdateMlModelRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateMlModelRequest.Builder,UpdateMlModelRequest>
@Generated("software.amazon.awssdk:codegen")
public final class UpdateMlModelRequest
extends MachineLearningRequest
implements ToCopyableBuilder<UpdateMlModelRequest.Builder,UpdateMlModelRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic UpdateMlModelRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ID assigned to theMLModelduring creation.final StringA user-supplied name or description of theMLModel.final FloatTheScoreThresholdused in binary classificationMLModelthat marks the boundary between a positive prediction and a negative prediction.static Class<? extends UpdateMlModelRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
mlModelId
The ID assigned to the
MLModelduring creation.- Returns:
- The ID assigned to the
MLModelduring creation.
-
mlModelName
A user-supplied name or description of the
MLModel.- Returns:
- A user-supplied name or description of the
MLModel.
-
scoreThreshold
The
ScoreThresholdused in binary classificationMLModelthat marks the boundary between a positive prediction and a negative prediction.Output values greater than or equal to the
ScoreThresholdreceive a positive result from theMLModel, such astrue. Output values less than theScoreThresholdreceive a negative response from theMLModel, such asfalse.- Returns:
- The
ScoreThresholdused in binary classificationMLModelthat marks the boundary between a positive prediction and a negative prediction.Output values greater than or equal to the
ScoreThresholdreceive a positive result from theMLModel, such astrue. Output values less than theScoreThresholdreceive a negative response from theMLModel, such asfalse.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateMlModelRequest.Builder,UpdateMlModelRequest> - Specified by:
toBuilderin classMachineLearningRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-