Uses of Enum
software.amazon.awssdk.services.machinelearning.model.Algorithm
Packages that use Algorithm
-
Uses of Algorithm in software.amazon.awssdk.services.machinelearning.model
Methods in software.amazon.awssdk.services.machinelearning.model that return AlgorithmModifier and TypeMethodDescriptionfinal AlgorithmMLModel.algorithm()The algorithm used to train theMLModel.static AlgorithmUse this in place of valueOf to convert the raw string returned by the service into the enum value.static AlgorithmReturns the enum constant of this type with the specified name.static Algorithm[]Algorithm.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.machinelearning.model that return types with arguments of type AlgorithmMethods in software.amazon.awssdk.services.machinelearning.model with parameters of type AlgorithmModifier and TypeMethodDescriptionThe algorithm used to train theMLModel.