Uses of Class
software.amazon.awssdk.services.machinelearning.model.GetDataSourceResponse
Packages that use GetDataSourceResponse
Package
Description
Definition of the public APIs exposed by Amazon Machine Learning
-
Uses of GetDataSourceResponse in software.amazon.awssdk.services.machinelearning
Methods in software.amazon.awssdk.services.machinelearning that return GetDataSourceResponseModifier and TypeMethodDescriptiondefault GetDataSourceResponseMachineLearningClient.getDataSource(Consumer<GetDataSourceRequest.Builder> getDataSourceRequest) Returns aDataSourcethat includes metadata and data file information, as well as the current status of theDataSource.default GetDataSourceResponseMachineLearningClient.getDataSource(GetDataSourceRequest getDataSourceRequest) Returns aDataSourcethat includes metadata and data file information, as well as the current status of theDataSource.Methods in software.amazon.awssdk.services.machinelearning that return types with arguments of type GetDataSourceResponseModifier and TypeMethodDescriptiondefault CompletableFuture<GetDataSourceResponse>MachineLearningAsyncClient.getDataSource(Consumer<GetDataSourceRequest.Builder> getDataSourceRequest) Returns aDataSourcethat includes metadata and data file information, as well as the current status of theDataSource.default CompletableFuture<GetDataSourceResponse>MachineLearningAsyncClient.getDataSource(GetDataSourceRequest getDataSourceRequest) Returns aDataSourcethat includes metadata and data file information, as well as the current status of theDataSource.