All Classes and Interfaces

Class
Description
 
 
AddTagsRequest Marshaller
Amazon ML returns the following elements.
 
The function used to train an MLModel.
An AWS Arn.
 
Represents the output of a GetBatchPrediction operation.
 
A list of the variables to use in searching or filtering BatchPrediction.
 
 
Represents the output of a CreateBatchPrediction operation, and is an acknowledgement that Amazon ML received the request.
 
 
 
Represents the output of a CreateDataSourceFromRDS operation, and is an acknowledgement that Amazon ML received the request.
 
 
 
Represents the output of a CreateDataSourceFromRedshift operation, and is an acknowledgement that Amazon ML received the request.
 
 
 
Represents the output of a CreateDataSourceFromS3 operation, and is an acknowledgement that Amazon ML received the request.
 
 
 
Represents the output of a CreateEvaluation operation, and is an acknowledgement that Amazon ML received the request.
 
 
 
Represents the output of a CreateMLModel operation, and is an acknowledgement that Amazon ML received the request.
 
 
 
Represents the output of an CreateRealtimeEndpoint operation.
 
Represents the output of the GetDataSource operation.
 
A list of the variables to use in searching or filtering DataSource.
 
 
 
 
 
 
 
Represents the output of a DeleteBatchPrediction operation.
 
 
 
Represents the output of a DeleteDataSource operation.
 
 
 
Represents the output of a DeleteEvaluation operation.
 
 
 
Represents the output of a DeleteMLModel operation.
 
 
 
Represents the output of an DeleteRealtimeEndpoint operation.
 
 
 
Amazon ML returns the following elements.
 
 
 
Represents the output of a DescribeBatchPredictions operation.
 
 
 
Represents the query results from a DescribeDataSources operation.
 
 
 
Represents the query results from a DescribeEvaluations operation.
 
 
 
Represents the output of a DescribeMLModels operation.
 
 
 
Amazon ML returns the following elements.
 
Contains the key values of DetailsMap:
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
Object status with the following possible values:
Represents the output of GetEvaluation operation.
 
A list of the variables to use in searching or filtering Evaluation.
 
 
Represents the output of a GetBatchPrediction operation and describes a BatchPrediction.
 
 
 
Represents the output of a GetDataSource operation and describes a DataSource.
 
 
 
Represents the output of a GetEvaluation operation and describes an Evaluation.
 
 
 
Represents the output of a GetMLModel operation, and provides detailed information about a MLModel.
 
A second request to use or change an object was not allowed.
 
Identifiers for variables declared within the rule engine, e.g.
An error on the server occurred when trying to process a request.
 
An error on the client occurred.
 
 
 
 
An intermediate value for JMESPath expressions, encapsulating the different data types supported by JMESPath and the operations on that data.
The subscriber exceeded the maximum number of operations.
 
Service client for accessing Amazon Machine Learning asynchronously.
A builder for creating an instance of MachineLearningAsyncClient.
Waiter utility class that polls a resource until a desired state is reached or until it is determined that the resource will never enter into the desired state.
 
 
The parameters object used to resolve the auth schemes for the MachineLearning service.
An auth scheme provider for MachineLearning service.
This includes configuration specific to Amazon Machine Learning that is supported by both MachineLearningClientBuilder and MachineLearningAsyncClientBuilder.
Service client for accessing Amazon Machine Learning.
A builder for creating an instance of MachineLearningClient.
 
The parameters object used to resolve an endpoint for the MachineLearning service.
 
An endpoint provider for MachineLearning.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
 
Waiter utility class that polls a resource until a desired state is reached or until it is determined that the resource will never enter into the desired state.
 
Represents the output of a GetMLModel operation.
 
 
 
 
 
 
 
 
 
 
Measurements of how well the MLModel performed on known observations.
 
Predict calls are sent to a predictor-specific endpoint.
The output from a Predict operation:
 
The exception is thrown when a predict request is made to an unmounted MLModel.
 
 
 
PredictRequest Marshaller
 
 
 
CreateXxx API calls require a unique (for all time!) ID parameter for idempotency.
The database details of an Amazon RDS database.
 
The database credentials to connect to a database on an RDS DB instance.
 
The data specification of an Amazon Relational Database Service (Amazon RDS) DataSource.
 
The datasource details that are specific to Amazon RDS.
 
Describes the real-time endpoint information for an MLModel.
 
 
Describes the database details required to connect to an Amazon Redshift database.
 
Describes the database credentials for connecting to a database on an Amazon Redshift cluster.
 
Describes the data specification of an Amazon Redshift DataSource.
 
Describes the DataSource details specific to Amazon Redshift.
 
 
 
A specified resource cannot be located.
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
Describes the data specification of a DataSource.
 
 
The sort order specified in a listing condition.
A custom key-value pair associated with an ML object, such as an ML model.
 
 
 
 
 
 
Represents the output of an UpdateBatchPrediction operation.
 
 
 
Represents the output of an UpdateDataSource operation.
 
 
 
Represents the output of an UpdateEvaluation operation.
 
 
 
Represents the output of an UpdateMLModel operation.
 
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.
Contains classes used at runtime by the code generator classes for waiter acceptors generated from JMESPath expressions.
A WaiterAcceptor implementation that checks for a specific HTTP response status, regardless of whether it's reported by a response or an exception.