Class CreateBatchPredictionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateBatchPredictionRequest.Builder,CreateBatchPredictionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe ID of theDataSourcethat points to the group of observations to predict.final StringA user-supplied ID that uniquely identifies theBatchPrediction.final StringA user-supplied name or description of theBatchPrediction.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ID of theMLModelthat will generate predictions for the group of observations.final StringThe location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results.static Class<? extends CreateBatchPredictionRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
batchPredictionId
A user-supplied ID that uniquely identifies the
BatchPrediction.- Returns:
- A user-supplied ID that uniquely identifies the
BatchPrediction.
-
batchPredictionName
A user-supplied name or description of the
BatchPrediction.BatchPredictionNamecan only use the UTF-8 character set.- Returns:
- A user-supplied name or description of the
BatchPrediction.BatchPredictionNamecan only use the UTF-8 character set.
-
mlModelId
The ID of the
MLModelthat will generate predictions for the group of observations.- Returns:
- The ID of the
MLModelthat will generate predictions for the group of observations.
-
batchPredictionDataSourceId
The ID of the
DataSourcethat points to the group of observations to predict.- Returns:
- The ID of the
DataSourcethat points to the group of observations to predict.
-
outputUri
The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results. The following substrings are not allowed in the
s3 keyportion of theoutputURIfield: ':', '//', '/./', '/../'.Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the Amazon Machine Learning Developer Guide.
- Returns:
- The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch
prediction results. The following substrings are not allowed in the
s3 keyportion of theoutputURIfield: ':', '//', '/./', '/../'.Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the Amazon Machine Learning Developer Guide.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateBatchPredictionRequest.Builder,CreateBatchPredictionRequest> - Specified by:
toBuilderin classMachineLearningRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-