Class CreateDataSourceFromRdsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateDataSourceFromRdsRequest.Builder,CreateDataSourceFromRdsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final BooleanThe compute statistics for aDataSource.final StringA user-supplied ID that uniquely identifies theDataSource.final StringA user-supplied name or description of theDataSource.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final RDSDataSpecrdsData()The data specification of an Amazon RDSDataSource:final StringroleARN()The role that Amazon ML assumes on behalf of the user to create and activate a data pipeline in the user's account and copy data using theSelectSqlQueryquery from Amazon RDS to Amazon S3.static Class<? extends CreateDataSourceFromRdsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
dataSourceId
A user-supplied ID that uniquely identifies the
DataSource. Typically, an Amazon Resource Number (ARN) becomes the ID for aDataSource.- Returns:
- A user-supplied ID that uniquely identifies the
DataSource. Typically, an Amazon Resource Number (ARN) becomes the ID for aDataSource.
-
dataSourceName
A user-supplied name or description of the
DataSource.- Returns:
- A user-supplied name or description of the
DataSource.
-
rdsData
The data specification of an Amazon RDS
DataSource:-
DatabaseInformation -
-
DatabaseName- The name of the Amazon RDS database. -
InstanceIdentifier- A unique identifier for the Amazon RDS database instance.
-
-
DatabaseCredentials - AWS Identity and Access Management (IAM) credentials that are used to connect to the Amazon RDS database.
-
ResourceRole - A role (DataPipelineDefaultResourceRole) assumed by an EC2 instance to carry out the copy task from Amazon RDS to Amazon Simple Storage Service (Amazon S3). For more information, see Role templates for data pipelines.
-
ServiceRole - A role (DataPipelineDefaultRole) assumed by the AWS Data Pipeline service to monitor the progress of the copy task from Amazon RDS to Amazon S3. For more information, see Role templates for data pipelines.
-
SecurityInfo - The security information to use to access an RDS DB instance. You need to set up appropriate ingress rules for the security entity IDs provided to allow access to the Amazon RDS instance. Specify a [
SubnetId,SecurityGroupIds] pair for a VPC-based RDS DB instance. -
SelectSqlQuery - A query that is used to retrieve the observation data for the
Datasource. -
S3StagingLocation - The Amazon S3 location for staging Amazon RDS data. The data retrieved from Amazon RDS using
SelectSqlQueryis stored in this location. -
DataSchemaUri - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
- Returns:
- The data specification of an Amazon RDS
DataSource:-
DatabaseInformation -
-
DatabaseName- The name of the Amazon RDS database. -
InstanceIdentifier- A unique identifier for the Amazon RDS database instance.
-
-
DatabaseCredentials - AWS Identity and Access Management (IAM) credentials that are used to connect to the Amazon RDS database.
-
ResourceRole - A role (DataPipelineDefaultResourceRole) assumed by an EC2 instance to carry out the copy task from Amazon RDS to Amazon Simple Storage Service (Amazon S3). For more information, see Role templates for data pipelines.
-
ServiceRole - A role (DataPipelineDefaultRole) assumed by the AWS Data Pipeline service to monitor the progress of the copy task from Amazon RDS to Amazon S3. For more information, see Role templates for data pipelines.
-
SecurityInfo - The security information to use to access an RDS DB instance. You need to set up appropriate ingress rules for the security entity IDs provided to allow access to the Amazon RDS instance. Specify a [
SubnetId,SecurityGroupIds] pair for a VPC-based RDS DB instance. -
SelectSqlQuery - A query that is used to retrieve the observation data for the
Datasource. -
S3StagingLocation - The Amazon S3 location for staging Amazon RDS data. The data retrieved from Amazon RDS using
SelectSqlQueryis stored in this location. -
DataSchemaUri - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
-
-
-
roleARN
The role that Amazon ML assumes on behalf of the user to create and activate a data pipeline in the user's account and copy data using the
SelectSqlQueryquery from Amazon RDS to Amazon S3.- Returns:
- The role that Amazon ML assumes on behalf of the user to create and activate a data pipeline in the
user's account and copy data using the
SelectSqlQueryquery from Amazon RDS to Amazon S3.
-
computeStatistics
The compute statistics for a
DataSource. The statistics are generated from the observation data referenced by aDataSource. Amazon ML uses the statistics internally duringMLModeltraining. This parameter must be set totrueif theDataSourceneeds to be used forMLModeltraining.- Returns:
- The compute statistics for a
DataSource. The statistics are generated from the observation data referenced by aDataSource. Amazon ML uses the statistics internally duringMLModeltraining. This parameter must be set totrueif theDataSourceneeds to be used forMLModeltraining.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateDataSourceFromRdsRequest.Builder,CreateDataSourceFromRdsRequest> - Specified by:
toBuilderin classMachineLearningRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-