Class CreateDataSourceFromRedshiftRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateDataSourceFromRedshiftRequest.Builder,CreateDataSourceFromRedshiftRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final BooleanThe compute statistics for aDataSource.final StringA user-supplied ID that uniquely identifies theDataSource.final StringA user-supplied name or description of theDataSource.final RedshiftDataSpecdataSpec()The data specification of an Amazon RedshiftDataSource:final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringroleARN()A fully specified role Amazon Resource Name (ARN).static Class<? extends CreateDataSourceFromRedshiftRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
dataSourceId
A user-supplied ID that uniquely identifies the
DataSource.- Returns:
- A user-supplied ID that uniquely identifies the
DataSource.
-
dataSourceName
A user-supplied name or description of the
DataSource.- Returns:
- A user-supplied name or description of the
DataSource.
-
dataSpec
The data specification of an Amazon Redshift
DataSource:-
DatabaseInformation -
-
DatabaseName- The name of the Amazon Redshift database. -
ClusterIdentifier- The unique ID for the Amazon Redshift cluster.
-
-
DatabaseCredentials - The AWS Identity and Access Management (IAM) credentials that are used to connect to the Amazon Redshift database.
-
SelectSqlQuery - The query that is used to retrieve the observation data for the
Datasource. -
S3StagingLocation - The Amazon Simple Storage Service (Amazon S3) location for staging Amazon Redshift data. The data retrieved from Amazon Redshift using the
SelectSqlQueryquery is stored in this location. -
DataSchemaUri - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
DataSource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
- Returns:
- The data specification of an Amazon Redshift
DataSource:-
DatabaseInformation -
-
DatabaseName- The name of the Amazon Redshift database. -
ClusterIdentifier- The unique ID for the Amazon Redshift cluster.
-
-
DatabaseCredentials - The AWS Identity and Access Management (IAM) credentials that are used to connect to the Amazon Redshift database.
-
SelectSqlQuery - The query that is used to retrieve the observation data for the
Datasource. -
S3StagingLocation - The Amazon Simple Storage Service (Amazon S3) location for staging Amazon Redshift data. The data retrieved from Amazon Redshift using the
SelectSqlQueryquery is stored in this location. -
DataSchemaUri - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
DataSource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
-
-
-
roleARN
A fully specified role Amazon Resource Name (ARN). Amazon ML assumes the role on behalf of the user to create the following:
-
A security group to allow Amazon ML to execute the
SelectSqlQueryquery on an Amazon Redshift cluster -
An Amazon S3 bucket policy to grant Amazon ML read/write permissions on the
S3StagingLocation
- Returns:
- A fully specified role Amazon Resource Name (ARN). Amazon ML assumes the role on behalf of the user to
create the following:
-
A security group to allow Amazon ML to execute the
SelectSqlQueryquery on an Amazon Redshift cluster -
An Amazon S3 bucket policy to grant Amazon ML read/write permissions on the
S3StagingLocation
-
-
-
computeStatistics
The compute statistics for a
DataSource. The statistics are generated from the observation data referenced by aDataSource. Amazon ML uses the statistics internally duringMLModeltraining. This parameter must be set totrueif theDataSourceneeds to be used forMLModeltraining.- Returns:
- The compute statistics for a
DataSource. The statistics are generated from the observation data referenced by aDataSource. Amazon ML uses the statistics internally duringMLModeltraining. This parameter must be set totrueif theDataSourceneeds to be used forMLModeltraining.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateDataSourceFromRedshiftRequest.Builder,CreateDataSourceFromRedshiftRequest> - Specified by:
toBuilderin classMachineLearningRequest
-
builder
-
serializableBuilderClass
public static Class<? extends CreateDataSourceFromRedshiftRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-