Class CreateDataSourceFromS3Request
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateDataSourceFromS3Request.Builder,CreateDataSourceFromS3Request>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final BooleanThe compute statistics for aDataSource.final StringA user-supplied identifier that uniquely identifies theDataSource.final StringA user-supplied name or description of theDataSource.final S3DataSpecdataSpec()The data specification of aDataSource:final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends CreateDataSourceFromS3Request.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
dataSourceId
A user-supplied identifier that uniquely identifies the
DataSource.- Returns:
- A user-supplied identifier that uniquely identifies the
DataSource.
-
dataSourceName
A user-supplied name or description of the
DataSource.- Returns:
- A user-supplied name or description of the
DataSource.
-
dataSpec
The data specification of a
DataSource:-
DataLocationS3 - The Amazon S3 location of the observation data.
-
DataSchemaLocationS3 - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
- Returns:
- The data specification of a
DataSource:-
DataLocationS3 - The Amazon S3 location of the observation data.
-
DataSchemaLocationS3 - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
-
-
-
computeStatistics
The compute statistics for a
DataSource. The statistics are generated from the observation data referenced by aDataSource. Amazon ML uses the statistics internally duringMLModeltraining. This parameter must be set totrueif theDataSourceneeds to be used forMLModeltraining.- Returns:
- The compute statistics for a
DataSource. The statistics are generated from the observation data referenced by aDataSource. Amazon ML uses the statistics internally duringMLModeltraining. This parameter must be set totrueif theDataSourceneeds to be used forMLModeltraining.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateDataSourceFromS3Request.Builder,CreateDataSourceFromS3Request> - Specified by:
toBuilderin classMachineLearningRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-