Class CreateMlModelResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CreateMlModelResponse.Builder,CreateMlModelResponse>

@Generated("software.amazon.awssdk:codegen") public final class CreateMlModelResponse extends MachineLearningResponse implements ToCopyableBuilder<CreateMlModelResponse.Builder,CreateMlModelResponse>

Represents the output of a CreateMLModel operation, and is an acknowledgement that Amazon ML received the request.

The CreateMLModel operation is asynchronous. You can poll for status updates by using the GetMLModel operation and checking the Status parameter.